==> nan_common_utils-0.0.11.tar.gz: lib/nan_photo_view_page.dart <==

import 'package:flutter/material.dart';
import 'package:nan_common_utils/nan_util.dart';
import 'package:nan_common_utils/nan_widget_util.dart';
import 'package:photo_view/photo_view.dart';
import 'package:photo_view/photo_view_gallery.dart';

class PhotoViewPage extends StatefulWidget {
  final List photoList;
  final int index;
  final int checkPhotoType;
  PhotoViewPage({this.photoList, this.index,this.checkPhotoType=NanCheckPhotoType.NetType});
  @override
  _PhotoViewPageState createState() => _PhotoViewPageState();
}

class _PhotoViewPageState extends State<PhotoViewPage> {
  
  int currentIndex = 0;
  int initialIndex; //初始index
  int length;
  int title;
  @override
  void initState() {
    currentIndex = widget.index;
    initialIndex = widget.index;
    length = widget.photoList.length;
    title = initialIndex + 1;
    super.initState();
  }

  void onPageChanged(int index) {
    setState(() {
      currentIndex = index;
      title = index + 1;
    });
  }

  Widget build(BuildContext context) {
    return Scaffold(
      appBar: NanWidgetUtil.commonAppBar(title: '$title / $length',elevation: 1),
      body: Container(
          decoration: BoxDecoration(
            color: Colors.black,
          ),
          constraints: BoxConstraints.expand(
            height: MediaQuery.of(context).size.height,
          ),
          child: Stack(
            alignment: Alignment.bottomRight,
            children: <Widget>[
              PhotoViewGallery.builder(
                scrollDirection: Axis.horizontal,
                scrollPhysics: const BouncingScrollPhysics(),
                builder: (BuildContext context, int index) {
                  if (widget.checkPhotoType == NanCheckPhotoType.NetType) {
                    return PhotoViewGalleryPageOptions(//网络图片
                      imageProvider: NetworkImage(widget.photoList[index]['filePath']),
                      initialScale: PhotoViewComputedScale.contained * 1,
                      heroTag: widget.photoList[index]['fileId'],
                    );
                  }
                  return PhotoViewGalleryPageOptions(//本地图片
                    imageProvider: AssetImage(widget.photoList[index]) ,
                    initialScale: PhotoViewComputedScale.contained,// * 0.8, 
                  ); 
                  
                },
                itemCount: widget.photoList.length,
                // loadingChild: widget.loadingChild,
                backgroundDecoration: BoxDecoration(
                  color: Colors.black,
                ),
                pageController: PageController(initialPage: initialIndex), //点进去哪页默认就显示哪一页
                onPageChanged: onPageChanged,
              ),
              // Container(
              //   padding: const EdgeInsets.all(10.0),
              //   child: Text(
              //     "Image ${currentIndex + 1}",
              //     style: const TextStyle(color: Colors.white, fontSize: 17.0, decoration: null),
              //   ),
              // )
            ],
          )),
    );
  }
}

==> nan_common_utils-0.0.37.tar.gz: lib/nan_photo_view_page.dart <==

import 'package:flutter/material.dart';
import 'package:nan_common_utils/nan_util.dart';
import 'package:nan_common_utils/nan_widget_util.dart';
import 'package:photo_view/photo_view.dart';
import 'package:photo_view/photo_view_gallery.dart';

class PhotoViewPage extends StatefulWidget {
  final List photoList;
  final int index;
  final int checkPhotoType;
  final Color navBgColor;
  PhotoViewPage({this.photoList, this.index,this.checkPhotoType=NanCheckPhotoType.NetType,this.navBgColor=Colors.white});
  @override
  _PhotoViewPageState createState() => _PhotoViewPageState();
}

class _PhotoViewPageState extends State<PhotoViewPage> {
  
  int currentIndex = 0;
  int initialIndex; //初始index
  int length;
  int title;
  @override
  void initState() {
    currentIndex = widget.index;
    initialIndex = widget.index;
    length = widget.photoList.length;
    title = initialIndex + 1;
    super.initState();
  }

  void onPageChanged(int index) {
    setState(() {
      currentIndex = index;
      title = index + 1;
    });
  }

  Widget build(BuildContext context) {
    return Scaffold(
      appBar: NanWidgetUtil.commonAppBar(title: '$title / $length',elevation: 1,bgColor: widget.navBgColor),
      body: Container(
          decoration: BoxDecoration(
            color: Colors.black,
          ),
          constraints: BoxConstraints.expand(
            height: MediaQuery.of(context).size.height,
          ),
          child: Stack(
            alignment: Alignment.bottomRight,
            children: <Widget>[
              PhotoViewGallery.builder(
                scrollDirection: Axis.horizontal,
                scrollPhysics: const BouncingScrollPhysics(),
                builder: (BuildContext context, int index) {
                  if (widget.checkPhotoType == NanCheckPhotoType.NetType) {
                    return PhotoViewGalleryPageOptions(//网络图片
                      imageProvider: NetworkImage(widget.photoList[index]['filePath']),
                      initialScale: PhotoViewComputedScale.contained * 1,
                      heroTag: widget.photoList[index]['fileId'],
                    );
                  }
                  return PhotoViewGalleryPageOptions(//本地图片
                    imageProvider: AssetImage(widget.photoList[index]) ,
                    initialScale: PhotoViewComputedScale.contained,// * 0.8, 
                  ); 
                  
                },
                itemCount: widget.photoList.length,
                // loadingChild: widget.loadingChild,
                backgroundDecoration: BoxDecoration(
                  color: Colors.black,
                ),
                pageController: PageController(initialPage: initialIndex), //点进去哪页默认就显示哪一页
                onPageChanged: onPageChanged,
              ),
              // Container(
              //   padding: const EdgeInsets.all(10.0),
              //   child: Text(
              //     "Image ${currentIndex + 1}",
              //     style: const TextStyle(color: Colors.white, fontSize: 17.0, decoration: null),
              //   ),
              // )
            ],
          )),
    );
  }
}
